@@ -107,13 +107,13 @@ class TestQa(TestCase):
 
 class TestJob(TestCase):
 
-    @given(job=Model.Jobs())
+    @given(job=Model.Duties())
     @with_database
     def test_job(self, job):
         assert job.save()
 
     # @skip('no test yet')
-    @given(job=Model.Jobs(),
+    @given(job=Model.Duties(),
            path=paths(pathlib_only=True))
     @with_database
     def test_job_files(self, job, path):
@@ -135,22 +135,21 @@ class TestSampleSheet(TestCase):
     def test_samplesheet(self, **kwargs):
         assert models.SampleSheet.create(**kwargs)
 
-    @skip('broken')
+    # @skip('broken')
     @with_database
     def test_get_unused_sheets(self):
-        self.flow = flow = models.Flowcell.create(consumable_id="TEST|TEST|TEST", consumable_type="TEST|TEST|TEST", path="TEST/TEST/TEST")
-        self.run = models.Run.create(pk=100, library_id='x', name="TEST", flowcell=flow, path="TEST/TEST/TEST")
+        # self.flow = flow = models.Flowcell.create(consumable_id="TEST|TEST|TEST", consumable_type="TEST|TEST|TEST", path="TEST/TEST/TEST")
+        self.run = models.Run.create(pk=100, library_id='x', name="TEST", path="TEST/TEST/TEST")
         self.assertFalse(models.SampleSheet.get_unused_sheets().count())
         models.SampleSheet.create(path="TEST")
         self.assertEqual(models.SampleSheet.get_unused_sheets().count(), 1)
 
-    @skip('broken')
-    @seed(5249283748837843916514315999694345497)
+    # @skip('broken')
     @given(ss=Model.Samplesheets())
     @with_database
     def test_new_sheet_from_message(self, ss):
-        flow = models.Flowcell.create(consumable_id="TEST|TEST|TEST", consumable_type="TEST|TEST|TEST", path="TEST/TEST/TEST")
-        run = models.Run.create(pk=100, library_id='x', name="TEST", flowcell=flow, path="TEST/TEST/TEST")
+        # flow = models.Flowcell.create(consumable_id="TEST|TEST|TEST", consumable_type="TEST|TEST|TEST", path="TEST/TEST/TEST")
+        run = models.Run.create(pk=100, library_id='x', name="TEST", path="TEST/TEST/TEST")
         s = models.SampleSheet.new_sheet_from_message(ss, run)
         self.assertEqual(run.sample_sheet, s)
 
@@ -185,7 +184,7 @@ class TestFile(TestCase):
            checksum=strat.text(),
            last_modified=strat.datetimes(),
            exported=strat.booleans(),
-           job=Model.Jobs())
+           job=Model.Duties())
     @with_database
     def test_job_spawn(self, job, **k):
         fi = models.File.create(**k)
